@@ -13,7 +13,7 @@
 
 {-|
 Module:      Data.Deriving.Internal
-Copyright:   (C) 2015-2016 Ryan Scott
+Copyright:   (C) 2015-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Portability: Template Haskell
@@ -2070,6 +2070,9 @@ pureValName = mkNameG_v "base" "GHC.Base" "pure"
 apValName :: Name
 apValName = mkNameG_v "base" "GHC.Base" "<*>"
 
+liftA2ValName :: Name
+liftA2ValName = mkNameG_v "base" "GHC.Base" "liftA2"
+
 mappendValName :: Name
 mappendValName = mkNameG_v "base" "GHC.Base" "mappend"
 
@@ -2082,6 +2085,9 @@ pureValName = mkNameG_v "base" "Control.Applicative" "pure"
 apValName :: Name
 apValName = mkNameG_v "base" "Control.Applicative" "<*>"
 
+liftA2ValName :: Name
+liftA2ValName = mkNameG_v "base" "Control.Applicative" "liftA2"
+
 mappendValName :: Name
 mappendValName = mkNameG_v "base" "Data.Monoid" "mappend"
 
@@ -2293,3 +2299,14 @@ unApplyValName :: Name
 unApplyValName = mkNameG_v derivingCompatPackageKey "Data.Deriving.Internal" "unApply"
 # endif
 #endif
+
+#if MIN_VERSION_base(4,10,0)
+showCommaSpaceValName :: Name
+showCommaSpaceValName = mkNameG_v "base" "GHC.Show" "showCommaSpace"
+#else
+showCommaSpace :: ShowS
+showCommaSpace = showString ", "
+
+showCommaSpaceValName :: Name
+showCommaSpaceValName = mkNameG_v derivingCompatPackageKey "Data.Deriving.Internal" "showCommaSpace"
+#endif
