@@ -2,7 +2,7 @@
 {-# LANGUAGE GADTs #-}
 {-|
 Module:      Data.Functor.Deriving.Internal
-Copyright:   (C) 2015-2016 Ryan Scott
+Copyright:   (C) 2015-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Portability: Template Haskell
@@ -470,7 +470,8 @@ traverseCombine conName _ args essQ = do
 
     let go :: [Exp] -> Exp
         go []     = VarE pureValName `AppE` conExp
-        go (e:es) = foldl' (\e1 e2 -> InfixE (Just e1) (VarE apValName) (Just e2))
-          (VarE fmapValName `AppE` conExp `AppE` e) es
+        go [e] = VarE fmapValName `AppE` conExp `AppE` e
+        go (e1:e2:es) = foldl' (\se1 se2 -> InfixE (Just se1) (VarE apValName) (Just se2))
+          (VarE liftA2ValName `AppE` conExp `AppE` e1 `AppE` e2) es
 
     return . go . rights $ ess
