@@ -3,7 +3,7 @@
 
 {-|
 Module:      Data.Ord.Deriving.Internal
-Copyright:   (C) 2015-2016 Ryan Scott
+Copyright:   (C) 2015-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Portability: Template Haskell
@@ -357,7 +357,7 @@ makeOrdFunForCon oFun v2 v2Hash ords singleConType
                          []
 
       tagLit :: Q Exp
-      tagLit = litE . integerL $ fromIntegral tag
+      tagLit = litE . intPrimL $ fromIntegral tag
 
   match (conP conName $ map varP as)
         (normalB innerRhs)
