@@ -2,7 +2,7 @@
 {-# LANGUAGE GADTs #-}
 {-|
 Module:      Text.Show.Deriving.Internal
-Copyright:   (C) 2015-2016 Ryan Scott
+Copyright:   (C) 2015-2017 Ryan Scott
 License:     BSD-style (see the file LICENSE)
 Maintainer:  Ryan Scott
 Portability: Template Haskell
@@ -394,7 +394,7 @@ makeShowForCon p sClass opts spls (RecC conName ts) = do
                                                                      (showString argNameBase) ""
                                          in [ varE showStringValName `appE` stringE (infixRec ++ " = ")
                                             , makeShowForArg 0 sClass opts conName tvMap argTy arg
-                                            , varE showStringValName `appE` stringE ", "
+                                            , varE showCommaSpaceValName
                                             ]
                                    )
                                    (zip3 ts argTys args)
